# pyqt-single-image-graphics-view
PyQt one image only QGraphicsView

## Requirements
* PyQt5 >= 5.8

## Setup
```pip3 install git+https://github.com/yjg30737/pyqt-single-image-graphics-view.git --upgrade```

## Method Overview
* ```setFilename(filename: str)```
* ```setPixmap(p: QPixmap)```

## See Also
* <a href="https://github.com/yjg30737/pyqt-fitting-graphics-view.git">pyqt-fitting-graphics-view</a>
